@@ -14,8 +14,8 @@ def task_mod_deps():
     for mod in MOD_IMPORTS.iterkeys():
         yield {'name': mod,
                'actions': [(print_deps,(mod,))],
-               # file_dep: False => make sure action is always executed
-               'file_dep': [mod, False],
+               'uptodate': [False],
+               'file_dep': [mod],
                'calc_dep': ["get_dep:%s" % mod],
                }
 
