@@ -7,8 +7,16 @@ from .task import Task
 
 class WaitTask(object):
     """Keep reference for waiting for a task"""
-    def __init__(self, task_name):
-        self.task_name = task_name
+    def __init__(self, waiting, wait_for):
+        self.waiting = waiting
+        self.wait_for = wait_for
+        # reference to python generator of TaskControl._add_task
+        self.task_gen = None
+
+    def __repr__(self):
+        return ("<%s waiting=%s wait_for=%s>" %
+                (self.__class__.__name__, self.waiting, self.wait_for))
+
 
 class WaitSelectTask(WaitTask):
     """Wait for a task to be selected to its execution
@@ -218,8 +226,7 @@ class TaskControl(object):
             for dyn_task in self._add_task(gen_id, dyn.name, include_setup):
                 yield dyn_task
             # wait for dynamic task to complete
-            if not include_setup:
-                yield WaitRunTask(dyn.name)
+            yield WaitRunTask(task_name, dyn.name)
             # refresh this task dependencies
             this_task.update_deps(dyn.values)
 
@@ -227,6 +234,7 @@ class TaskControl(object):
         for dependency in this_task.task_dep:
             for dep_task in self._add_task(gen_id, dependency, include_setup):
                 yield dep_task
+            yield WaitRunTask(task_name, dependency)
 
         # add itself
         yield self.tasks[task_name]
@@ -236,8 +244,8 @@ class TaskControl(object):
             # run_status None means task is waiting for other tasks
             # in order to check if up-to-date. so it needs to wait
             # before scheduling its setup-tasks.
-            if this_task.run_status is None and not include_setup:
-                yield WaitSelectTask(task_name)
+            if this_task.run_status is None:
+                yield WaitSelectTask(task_name, task_name)
 
             # this task should run, so schedule setup-tasks before itself
             if this_task.run_status == 'run' or include_setup:
@@ -248,6 +256,7 @@ class TaskControl(object):
                     for setup_dep in self._add_task(gen_id, setup_task,
                                                     include_setup):
                         yield setup_dep
+                    yield WaitRunTask(task_name, setup_task)
                 # re-send this task after setup_tasks are sent
                 yield self.tasks[task_name]
 
@@ -266,14 +275,12 @@ class TaskControl(object):
         # each selected task will create a tree (from dependencies) of
         # tasks to be processed
         tasks_to_run = self.selected_tasks[:]
-        # waiting task generators
-        # key (str): name of the task to wait for
-        # value (list): add_task generator waiting for this task
-        task_gens = {}
+        # waiting task generators list of WaitTask
+        wait_gens = []
         # current active task generator
         current_gen = None
         gen_id = 1
-        while tasks_to_run or task_gens or current_gen:
+        while tasks_to_run or wait_gens or current_gen:
             ## get task from (in order):
             # 1 - current task generator
             # 2 - waiting task generator
@@ -281,10 +288,11 @@ class TaskControl(object):
 
             # get task group from waiting queue
             if not current_gen:
-                for wait_name, wait in task_gens.iteritems():
-                    if wait.ready(self.tasks[wait_name].run_status):
-                        current_gen = task_gens[wait_name].task_gen
-                        del task_gens[wait_name]
+                for wait_task in wait_gens:
+                    status = self.tasks[wait_task.wait_for].run_status
+                    if wait_task.ready(status):
+                        current_gen = wait_task.task_gen
+                        wait_gens.remove(wait_task)
                         break
 
             # get task group from tasks_to_run
@@ -306,12 +314,12 @@ class TaskControl(object):
                 current_gen = None
                 continue
 
-            # str means this generator is on hold, add to waiting dict
             if isinstance(next_task, WaitTask):
-                if next_task not in task_gens:
+                # skip all waiting tasks, just getting a list of tasks...
+                if not include_setup:
                     next_task.task_gen = current_gen
-                    task_gens[next_task.task_name] = next_task
-                current_gen = None
+                    wait_gens.append(next_task)
+                    current_gen = None
             # get task from current group
             else:
                 assert isinstance(next_task, Task), next_task
