@@ -11,7 +11,7 @@ import anydbm as ddbm
 #import dbm as ddbm # test_corrupted_file fails
 #import gdbm as ddbm # ok <= TODO make this the default
 
-from . import json
+from .compat import json
 
 
 USE_FILE_TIMESTAMP = True
@@ -237,7 +237,7 @@ class DependencyBase(object):
     dictionary where key is a dependency (abs file path), and the value is the
     dependency signature.
     Apart from dependencies onther values are also saved on the task dictionary
-     * 'result:', 'run-once:', 'task:<task-name>', 'ignore:'
+     * 'result:', 'task:<task-name>', 'ignore:'
      * user(task) defined values are defined in '_values_:' sub-dict
 
     @ivar name: (string) filepath of the DB file
@@ -270,7 +270,10 @@ class DependencyBase(object):
 
         # save task result md5
         if task.result:
-            self._set(task.name, "result:", get_md5(task.result))
+            if isinstance(task.result, dict):
+                self._set(task.name, "result:", task.result)
+            else:
+                self._set(task.name, "result:", get_md5(task.result))
 
         # file-dep
         for dep in task.file_dep:
@@ -291,24 +294,25 @@ class DependencyBase(object):
 
 
     def get_values(self, task_name):
-        """get all saved values from a task"""
+        """get all saved values from a task
+        @return dict
+        """
         values = self._get(task_name, '_values_:')
         return values or {}
 
-    def get_value(self, name):
+    def get_value(self, task_id, key_name):
         """get saved value from task
-        @param name (str): taskid.argument-name
+        @param task_id (str)
+        @param key_name (str): key result dict of the value
         """
-        parts = name.rsplit('.', 1)
-        assert len(parts) == 2
-        taskid, arg_name = parts
-        if not self._in(taskid):
-            raise Exception("taskid '%s' has no computed value!" % taskid)
-        values = self.get_values(taskid)
-        if arg_name not in values:
+        if not self._in(task_id):
+            # FIXME do not use generic exception
+            raise Exception("taskid '%s' has no computed value!" % task_id)
+        values = self.get_values(task_id)
+        if key_name not in values:
             msg = "Invalid arg name. Task '%s' has no value for '%s'."
-            raise Exception(msg % (taskid, arg_name))
-        return values[arg_name]
+            raise Exception(msg % (task_id, key_name))
+        return values[key_name]
 
     def remove_success(self, task):
         """remove saved info from task"""
@@ -381,7 +385,7 @@ class DependencyBase(object):
         for dep in tuple(task.result_dep):
             result = self._get(dep, "result:")
             if ((result is None) or
-                (self._get(task.name,"task:" + dep) != result)):
+                (self._get(task.name, "task:" + dep) != result)):
                 status = 'run'
                 break
 
